# swas.py
this is just a joke module
<img align="right" src="https://yt3.ggpht.com/ytc/AAUvwnhCHvh874ka4dfgpPbTU7Zkfsu7qD5b4U2obdB9=s176-c-k-c0x00ffffff-no-rj" height="100" width="100">
made by Mossyegghead and DistinctNoot
